@@ -1,15 +1,22 @@
 from __future__ import annotations
 
 import os
+import io
+import ast
+import logging
+import textwrap
 from os import path as osp
 from typing import cast, TYPE_CHECKING
 
 import click
+from click.shell_completion import get_completion_class
+from rich.console import Console
+from rich.text import Text
 
 from .cli_core import select_dbx_path_dialog
 from .dialogs import confirm, select
-from .output import ok, echo, Table, TextField, DateField, warn
-from .utils import get_term_width
+from .output import ok, warn, echo, echo_via_pager, RichDateField, rich_table
+from .utils import get_term_size
 from .common import convert_api_errors, existing_config_option, inject_proxy
 from .core import DropboxPath, ConfigKey, CliException
 
@@ -21,7 +28,6 @@ if TYPE_CHECKING:
 @click.argument("new_path", required=False, type=click.Path(writable=True))
 @inject_proxy(fallback=True, existing_config=True)
 def move_dir(m: Maestral, new_path: str) -> None:
-
     new_path = new_path or select_dbx_path_dialog(m.config_name)
     new_path = osp.realpath(osp.expanduser(new_path))
 
@@ -43,10 +49,7 @@ Rebuilding may take several minutes, depending on the size of your Dropbox.
 @inject_proxy(fallback=True, existing_config=True)
 @convert_api_errors
 def rebuild_index(m: Maestral, yes: bool) -> None:
-
-    import textwrap
-
-    width = get_term_width()
+    size = get_term_size()
 
     msg = textwrap.fill(
         "Rebuilding the index may take several minutes, depending on the size of "
@@ -54,13 +57,12 @@ def rebuild_index(m: Maestral, yes: bool) -> None:
         "has completed. If you stop the daemon during the process, rebuilding will "
         "start again on the next launch.\nIf the daemon is not currently running, "
         "a rebuild will be scheduled for the next startup.",
-        width=width,
+        width=size.columns,
     )
 
     echo(msg + "\n")
 
     if yes or confirm("Do you want to continue?", default=False):
-
         m.rebuild_index()
 
         if m.running:
@@ -82,17 +84,13 @@ def rebuild_index(m: Maestral, yes: bool) -> None:
 @inject_proxy(fallback=True, existing_config=True)
 @convert_api_errors
 def revs(m: Maestral, dropbox_path: str, limit: int) -> None:
+    table = rich_table("Revision", "Modified Time")
 
-    entries = m.list_revisions(dropbox_path, limit=limit)
+    for entry in m.list_revisions(dropbox_path, limit=limit):
+        table.add_row(Text(entry.rev), RichDateField(entry.client_modified))
 
-    table = Table(["Revision", "Modified Time"])
-
-    for entry in entries:
-        table.append([TextField(entry.rev), DateField(entry.client_modified)])
-
-    echo("")
-    table.echo()
-    echo("")
+    console = Console()
+    console.print(table)
 
 
 @click.command(
@@ -145,8 +143,8 @@ def diff(
         modified_dates: list[str] = []
 
         for entry in entries:
-            field = DateField(entry.client_modified)
-            modified_dates.append(field.format(40)[0])
+            field = RichDateField(entry.client_modified)
+            modified_dates.append(field.format(40))
 
         dbx_path = entries[0].path_display
         local_path = m.to_local_path(dbx_path)
@@ -190,12 +188,12 @@ def diff(
     # If an unknown file type was found, everything that doesn't match
     # 'text/*', an error message gets printed.
 
-    click.echo("Loading ...\r", nl=False)
+    echo("Loading ...\r", nl=False)
 
     diff_output = m.get_file_diff(old_rev, new_rev)
 
     if len(diff_output) == 0:
-        click.echo("There are no changes between the two revisions.")
+        echo("There are no changes between the two revisions.")
         return
 
     def color(ind: int, line: str) -> str:
@@ -222,9 +220,9 @@ def diff(
 
     # Enter pager if diff is too long
     if len(diff_output) > 30 and not no_pager:
-        click.echo_via_pager("".join(diff_output))
+        echo_via_pager("".join(diff_output))
     else:
-        click.echo("".join(diff_output))
+        echo("".join(diff_output))
 
 
 @click.command(
@@ -247,14 +245,13 @@ If no revision number is given, old revisions will be listed.
 @inject_proxy(fallback=True, existing_config=True)
 @convert_api_errors
 def restore(m: Maestral, dropbox_path: str, rev: str, limit: int) -> None:
-
     if not rev:
         echo("Loading...\r", nl=False)
         entries = m.list_revisions(dropbox_path, limit=limit)
         dates = []
         for entry in entries:
-            field = DateField(entry.client_modified)
-            dates.append(field.format(40)[0])
+            field = RichDateField(entry.client_modified)
+            dates.append(field.format(40))
 
         index = select(
             message="Select a version to restore:",
@@ -270,7 +267,7 @@ def restore(m: Maestral, dropbox_path: str, rev: str, limit: int) -> None:
 
 
 @click.group(help="View and manage the log.")
-def log():
+def log() -> None:
     pass
 
 
@@ -280,7 +277,6 @@ def log():
 )
 @existing_config_option
 def log_show(external: bool, config_name: str) -> None:
-
     from ..utils.appdirs import get_log_path
 
     log_file = get_log_path("maestral", config_name + ".log")
@@ -291,7 +287,7 @@ def log_show(external: bool, config_name: str) -> None:
         try:
             with open(log_file) as f:
                 text = f.read()
-            click.echo_via_pager(text)
+            echo_via_pager(text)
         except OSError:
             res = 1
         else:
@@ -304,7 +300,6 @@ def log_show(external: bool, config_name: str) -> None:
 @log.command(name="clear", help="Clear the log files.")
 @existing_config_option
 def log_clear(config_name: str) -> None:
-
     from ..utils.appdirs import get_log_path
 
     log_dir = get_log_path("maestral")
@@ -336,9 +331,6 @@ def log_clear(config_name: str) -> None:
 )
 @inject_proxy(fallback=True, existing_config=True)
 def log_level(m: Maestral, level_name: str) -> None:
-
-    import logging
-
     if level_name:
         m.log_level = cast(int, getattr(logging, level_name))
         ok(f"Log level set to {level_name}.")
@@ -377,7 +369,7 @@ Currently available config keys are:
 - download: if download sync is enabled
 """,
 )
-def config():
+def config() -> None:
     pass
 
 
@@ -385,7 +377,6 @@ def config():
 @click.argument("key", type=ConfigKey())
 @inject_proxy(fallback=True, existing_config=True)
 def config_get(m: Maestral, key: str) -> None:
-
     from ..config.main import KEY_SECTION_MAP
 
     # Check if the config key exists in any section.
@@ -413,8 +404,6 @@ instance, setting a boolean config value to 1 will actually set it to True.
 @inject_proxy(fallback=True, existing_config=True)
 @convert_api_errors
 def config_set(m: Maestral, key: str, value: str) -> None:
-
-    import ast
     from ..config.main import KEY_SECTION_MAP, DEFAULTS_CONFIG
 
     section = KEY_SECTION_MAP.get(key, "")
@@ -442,8 +431,6 @@ def config_set(m: Maestral, key: str, value: str) -> None:
 @click.option("--no-pager", help="Don't use a pager for output.", is_flag=True)
 @existing_config_option
 def config_show(no_pager: bool, config_name: str) -> None:
-
-    import io
     from ..config import MaestralConfig
 
     conf = MaestralConfig(config_name)
@@ -451,9 +438,9 @@ def config_show(no_pager: bool, config_name: str) -> None:
     with io.StringIO() as fp:
         conf.write(fp)
         if no_pager:
-            click.echo(fp.getvalue())
+            echo(fp.getvalue())
         else:
-            click.echo_via_pager(fp.getvalue())
+            echo_via_pager(fp.getvalue())
 
 
 @click.command(
@@ -510,8 +497,6 @@ For the current user only:
 )
 @click.argument("shell", type=click.Choice(["bash", "zsh", "fish"]))
 def completion(shell: str) -> None:
-
-    from click.shell_completion import get_completion_class
     from .cli_main import main
 
     comp_cls = get_completion_class(shell)
@@ -523,6 +508,6 @@ def completion(shell: str) -> None:
     comp = comp_cls(main, {}, "maestral", "_MAESTRAL_COMPLETE")
 
     try:
-        click.echo(comp.source())
+        echo(comp.source())
     except RuntimeError as exc:
         warn(exc.args[0])
